@@ -41,6 +41,10 @@ class ClickReviewScope(ClickReview):
                              overrides=overrides)
 
         self.scopes = dict()
+
+        if self.manifest is None:
+            return
+
         for app in self.manifest['hooks']:
             if 'scope' not in self.manifest['hooks'][app]:
                 # msg("Skipped missing scope hook for '%s'" % app)
@@ -120,6 +124,7 @@ class ClickReviewScope(ClickReview):
             translated = ['description',
                           'displayname',
                           'searchhint']
+            internal = ['debugmode']
 
             missing = []
             t = 'info'
@@ -146,9 +151,9 @@ class ClickReviewScope(ClickReview):
             unknown = []
             for i in self.scopes[app]["scope_config"]['ScopeConfig'].keys():
                 f = i.lower()
-                if f not in required and f not in optional and \
+                if f not in required and f not in optional and f not in internal and \
                    (f.split("[")[0] not in translated or not
-                       re.search(r'.*\[[a-z][a-z](_[a-z][a-z])?\]$', f)):
+                       re.search('.*\[[a-z]{2,3}(_[a-z]{2,3})?\]$', f)):
                     unknown.append(f)
 
             if len(unknown) == 1:
@@ -162,3 +167,22 @@ class ClickReviewScope(ClickReview):
                     self.scopes[app]["ini_file_rel"],
                     ", ".join(unknown))
             self._add_result(t, n, s)
+
+            t = 'info'
+            n = self._get_check_name('ini_scope_internal_fields', app=app)
+            s = "OK"
+            forbidden = []
+            for r in internal:
+                if r in self.scopes[app]["scope_config"]['ScopeConfig']:
+                    forbidden.append(r)
+            if len(forbidden) == 1:
+                t = 'error'
+                s = "Forbidden field in '%s': %s" % (
+                    self.scopes[app]["ini_file_rel"],
+                    forbidden[0])
+            elif len(forbidden) > 1:
+                t = 'error'
+                s = "Forbidden fields in '%s': %s" % (
+                    self.scopes[app]["ini_file_rel"],
+                    ", ".join(forbidden))
+            self._add_result(t, n, s)
