@@ -50,6 +50,8 @@ TEST_BIN_PATH = dict()
 TEST_FRAMEWORK = dict()
 TEST_FRAMEWORK_POLICY = dict()
 TEST_FRAMEWORK_POLICY_UNKNOWN = []
+TEST_PKGFMT_TYPE = "click"
+TEST_PKGFMT_VERSION = "0.4"
 
 
 #
@@ -139,6 +141,9 @@ def _extract_security_manifest(self, app):
 
 def _get_security_manifest(self, app):
     '''Pretend we read the security manifest file'''
+    if TEST_PKGFMT_VERSION == "16.04":
+        return (app, json.loads(TEST_SECURITY[app]))
+
     return ("%s.apparmor" % app, json.loads(TEST_SECURITY[app]))
 
 
@@ -244,151 +249,154 @@ def _has_framework_in_metadir(self):
     return True
 
 
-# http://docs.python.org/3.4/library/unittest.mock-examples.html
-# Mock patching. Don't use decorators but instead patch in setUp() of the
-# child. Set up a list of patches, but don't start them. Create the helper
-# method mock_patch() to start all the patches. The child can do this in a
-# setUp() like so:
-#   import clickreviews.cr_tests as cr_tests
-#   class TestClickReviewFoo(cr_tests.TestClickReview):
-#       def setUp(self):
-#           # Monkey patch various file access classes. stop() is handled with
-#           # addCleanup in super()
-#           cr_tests.mock_patch()
-#           super()
-patches = []
-patches.append(patch('clickreviews.cr_common.ClickReview._check_path_exists',
-               _mock_func))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._extract_control_file',
-    _extract_control_file))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._extract_manifest_file',
-    _extract_manifest_file))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._extract_package_yaml',
-    _extract_package_yaml))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._extract_hashes_yaml',
-    _extract_hashes_yaml))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._path_join',
-    _path_join))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._get_sha512sum',
-    _get_sha512sum))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._extract_statinfo',
-    _extract_statinfo))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._extract_click_frameworks',
-    _extract_click_frameworks))
-patches.append(patch('clickreviews.cr_common.unpack_click', _mock_func))
-patches.append(patch('clickreviews.cr_common.raw_unpack_pkg', _mock_func))
-patches.append(patch('clickreviews.cr_common.ClickReview._list_all_files',
-               _mock_func))
-patches.append(patch(
-    'clickreviews.cr_common.ClickReview._list_all_compiled_binaries',
-    _mock_func))
-
-# lint overrides
-patches.append(patch(
-               'clickreviews.cr_lint.ClickReviewLint._list_control_files',
-               _mock_func))
-patches.append(patch('clickreviews.cr_lint.ClickReviewLint._list_all_files',
-               _mock_func))
-patches.append(patch(
-    'clickreviews.cr_lint.ClickReview._list_all_compiled_binaries',
-    _mock_func))
-patches.append(patch(
-    'clickreviews.cr_lint.ClickReviewLint._extract_readme_md',
-    _extract_readme_md))
-patches.append(patch(
-    'clickreviews.cr_lint.ClickReviewLint._check_innerpath_executable',
-    _check_innerpath_executable))
-
-# security overrides
-patches.append(patch(
-    'clickreviews.cr_security.ClickReviewSecurity._extract_security_manifest',
-    _extract_security_manifest))
-patches.append(patch(
-    'clickreviews.cr_security.ClickReviewSecurity._get_security_manifest',
-    _get_security_manifest))
-patches.append(patch(
-    'clickreviews.cr_security.ClickReviewSecurity._extract_security_profile',
-    _extract_security_profile))
-patches.append(patch(
-    'clickreviews.cr_security.ClickReviewSecurity._get_security_profile',
-    _get_security_profile))
-
-# desktop overrides
-patches.append(patch(
-    'clickreviews.cr_desktop.ClickReviewDesktop._extract_desktop_entry',
-    _extract_desktop_entry))
-patches.append(patch(
-    'clickreviews.cr_desktop.ClickReviewDesktop._get_desktop_entry',
-    _get_desktop_entry))
-patches.append(patch(
-    'clickreviews.cr_desktop.ClickReviewDesktop._extract_webapp_manifests',
-    _extract_webapp_manifests))
-
-# url-dispatcher overrides
-patches.append(patch(
-    'clickreviews.cr_url_dispatcher.ClickReviewUrlDispatcher._extract_url_dispatcher',
-    _extract_url_dispatcher))
-
-# scope overrides
-patches.append(patch(
-    'clickreviews.cr_scope.ClickReviewScope._extract_scopes',
-    _extract_scopes))
-
-# content-hub overrides
-patches.append(patch(
-    'clickreviews.cr_content_hub.ClickReviewContentHub._extract_content_hub',
-    _extract_content_hub))
-
-# online accounts overrides
-patches.append(patch(
-    'clickreviews.cr_online_accounts.ClickReviewAccounts._extract_account',
-    _extract_account))
-
-# push-helper overrides
-patches.append(patch(
-    'clickreviews.cr_push_helper.ClickReviewPushHelper._extract_push_helper',
-    _extract_push_helper))
-
-# bin-path overrides
-patches.append(patch(
-    'clickreviews.cr_bin_path.ClickReviewBinPath._extract_bin_path',
-    _extract_bin_path))
-patches.append(patch(
-    'clickreviews.cr_bin_path.ClickReviewBinPath._check_bin_path_executable',
-    _check_bin_path_executable))
-
-# framework overrides
-patches.append(patch(
-    'clickreviews.cr_framework.ClickReviewFramework._extract_framework',
-    _extract_framework))
-patches.append(patch(
-    'clickreviews.cr_framework.ClickReviewFramework._extract_framework_policy',
-    _extract_framework_policy))
-patches.append(patch(
-    'clickreviews.cr_framework.ClickReviewFramework._has_framework_in_metadir',
-    _has_framework_in_metadir))
+def _pkgfmt_type(self):
+    '''Pretend we found the pkgfmt type'''
+    return TEST_PKGFMT_TYPE
 
 
-def mock_patch():
-    '''Call in setup of child'''
-    global patches
-    for p in patches:
-        try:
-            p.start()
-        except ImportError:
-            # This is only needed because we are importing ClickReviewLint
-            # in the security tests and ClickReviewSecurity in the lint tests.
-            # If we move those patches outside of this file, then we can
-            # remove this.
-            pass
+def _pkgfmt_version(self):
+    '''Pretend we found the pkgfmt version'''
+    return TEST_PKGFMT_VERSION
+
+
+def _is_squashfs(self):
+    '''Pretend we discovered if it is a squashfs or not'''
+    return (TEST_PKGFMT_TYPE == "snap" and float(TEST_PKGFMT_VERSION) > 15.04)
+
+
+def create_patches():
+    # http://docs.python.org/3.4/library/unittest.mock-examples.html
+    # Mock patching. Don't use decorators but instead patch in setUp() of the
+    # child.
+    patches = []
+    patches.append(patch('clickreviews.cr_common.ClickReview._check_path_exists',
+                   _mock_func))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._extract_control_file',
+        _extract_control_file))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._extract_manifest_file',
+        _extract_manifest_file))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._extract_package_yaml',
+        _extract_package_yaml))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._extract_hashes_yaml',
+        _extract_hashes_yaml))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._path_join',
+        _path_join))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._get_sha512sum',
+        _get_sha512sum))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._extract_statinfo',
+        _extract_statinfo))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._extract_click_frameworks',
+        _extract_click_frameworks))
+    patches.append(patch('clickreviews.cr_common.unpack_click', _mock_func))
+    patches.append(patch('clickreviews.cr_common.raw_unpack_pkg', _mock_func))
+    patches.append(patch('clickreviews.cr_common.ClickReview._list_all_files',
+                   _mock_func))
+    patches.append(patch(
+        'clickreviews.cr_common.ClickReview._list_all_compiled_binaries',
+        _mock_func))
+
+    # lint overrides
+    patches.append(patch(
+                   'clickreviews.cr_lint.ClickReviewLint._list_control_files',
+                   _mock_func))
+    patches.append(patch('clickreviews.cr_lint.ClickReviewLint._list_all_files',
+                   _mock_func))
+    patches.append(patch(
+        'clickreviews.cr_lint.ClickReview._list_all_compiled_binaries',
+        _mock_func))
+    patches.append(patch(
+        'clickreviews.cr_lint.ClickReviewLint._extract_readme_md',
+        _extract_readme_md))
+    patches.append(patch(
+        'clickreviews.cr_lint.ClickReviewLint._check_innerpath_executable',
+        _check_innerpath_executable))
+
+    # security overrides
+    patches.append(patch(
+        'clickreviews.cr_security.ClickReviewSecurity._extract_security_manifest',
+        _extract_security_manifest))
+    patches.append(patch(
+        'clickreviews.cr_security.ClickReviewSecurity._get_security_manifest',
+        _get_security_manifest))
+    patches.append(patch(
+        'clickreviews.cr_security.ClickReviewSecurity._extract_security_profile',
+        _extract_security_profile))
+    patches.append(patch(
+        'clickreviews.cr_security.ClickReviewSecurity._get_security_profile',
+        _get_security_profile))
+
+    # desktop overrides
+    patches.append(patch(
+        'clickreviews.cr_desktop.ClickReviewDesktop._extract_desktop_entry',
+        _extract_desktop_entry))
+    patches.append(patch(
+        'clickreviews.cr_desktop.ClickReviewDesktop._get_desktop_entry',
+        _get_desktop_entry))
+    patches.append(patch(
+        'clickreviews.cr_desktop.ClickReviewDesktop._extract_webapp_manifests',
+        _extract_webapp_manifests))
+
+    # url-dispatcher overrides
+    patches.append(patch(
+        'clickreviews.cr_url_dispatcher.ClickReviewUrlDispatcher._extract_url_dispatcher',
+        _extract_url_dispatcher))
+
+    # scope overrides
+    patches.append(patch(
+        'clickreviews.cr_scope.ClickReviewScope._extract_scopes',
+        _extract_scopes))
+
+    # content-hub overrides
+    patches.append(patch(
+        'clickreviews.cr_content_hub.ClickReviewContentHub._extract_content_hub',
+        _extract_content_hub))
+
+    # online accounts overrides
+    patches.append(patch(
+        'clickreviews.cr_online_accounts.ClickReviewAccounts._extract_account',
+        _extract_account))
+
+    # push-helper overrides
+    patches.append(patch(
+        'clickreviews.cr_push_helper.ClickReviewPushHelper._extract_push_helper',
+        _extract_push_helper))
+
+    # bin-path overrides
+    patches.append(patch(
+        'clickreviews.cr_bin_path.ClickReviewBinPath._extract_bin_path',
+        _extract_bin_path))
+    patches.append(patch(
+        'clickreviews.cr_bin_path.ClickReviewBinPath._check_bin_path_executable',
+        _check_bin_path_executable))
+
+    # framework overrides
+    patches.append(patch(
+        'clickreviews.cr_framework.ClickReviewFramework._extract_framework',
+        _extract_framework))
+    patches.append(patch(
+        'clickreviews.cr_framework.ClickReviewFramework._extract_framework_policy',
+        _extract_framework_policy))
+    patches.append(patch(
+        'clickreviews.cr_framework.ClickReviewFramework._has_framework_in_metadir',
+        _has_framework_in_metadir))
+
+    # pkgfmt
+    patches.append(patch("clickreviews.cr_common.ClickReview._pkgfmt_type",
+                   _pkgfmt_type))
+    patches.append(patch("clickreviews.cr_common.ClickReview._pkgfmt_version",
+                   _pkgfmt_version))
+    patches.append(patch("clickreviews.cr_common.is_squashfs", _is_squashfs))
+    patches.append(patch("clickreviews.cr_lint.is_squashfs", _is_squashfs))
+
+    return patches
 
 
 class TestClickReview(TestCase):
@@ -446,6 +454,8 @@ class TestClickReview(TestCase):
         self.test_readme_md = self.test_control['Description']
         self._update_test_readme_md()
 
+        self.set_test_pkgfmt("click", "0.4")
+
         # hooks
         self.test_security_manifests = dict()
         self.test_security_profiles = dict()
@@ -463,6 +473,7 @@ class TestClickReview(TestCase):
         self.test_framework = dict()
         self.test_framework_policy = dict()
         self.test_framework_policy_unknown = []
+
         for app in self.test_manifest["hooks"].keys():
             # setup security manifest for each app
             self.set_test_security_manifest(app, 'policy_groups',
@@ -865,6 +876,12 @@ class TestClickReview(TestCase):
             self.test_security_profiles[app] = policy
         self._update_test_security_profiles()
 
+    def set_test_pkgfmt(self, t, v):
+        global TEST_PKGFMT_TYPE
+        global TEST_PKGFMT_VERSION
+        TEST_PKGFMT_TYPE = t
+        TEST_PKGFMT_VERSION = v
+
     def set_test_desktop(self, app, key, value, no_update=False):
         '''Set key in desktop file to value. If value is None, remove key'''
         if app not in self.test_desktop_files:
@@ -1107,9 +1124,10 @@ class TestClickReview(TestCase):
 
     def setUp(self):
         '''Make sure our patches are applied everywhere'''
-        global patches
+        patches = create_patches()
         for p in patches:
-            self.addCleanup(p.stop())
+            p.start()
+            self.addCleanup(p.stop)
 
     def tearDown(self):
         '''Make sure we reset everything to known good values'''
@@ -1155,6 +1173,10 @@ class TestClickReview(TestCase):
         TEST_FRAMEWORK_POLICY = dict()
         global TEST_FRAMEWORK_POLICY_UNKNOWN
         TEST_FRAMEWORK_POLICY_UNKNOWN = []
+        global TEST_PKGFMT_TYPE
+        TEST_PKGFMT_TYPE = "click"
+        global TEST_PKGFMT_VERSION
+        TEST_PKGFMT_VERSION = "0.4"
 
         self._reset_test_data()
         cr_common.recursive_rm(self.desktop_tmpdir)
