@@ -20,11 +20,6 @@ import clickreviews.cr_tests as cr_tests
 
 class TestClickReviewDesktop(cr_tests.TestClickReview):
     """Tests for the desktop review tool."""
-    def setUp(self):
-        # Monkey patch various file access classes. stop() is handled with
-        # addCleanup in super()
-        cr_tests.mock_patch()
-        super()
 
     def test_check_desktop_file(self):
         '''Test check_desktop_file()'''
@@ -901,3 +896,31 @@ class TestClickReviewDesktop(cr_tests.TestClickReview):
         r = c.click_report
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
+
+    def test_check_desktop_file_snappy_1504(self):
+        '''Test check_desktop_file() - snappy 15.04'''
+        self.set_test_pkgfmt("snap", "15.04")
+        c = ClickReviewDesktop(self.test_name)
+        c.check_desktop_file()
+        r = c.click_report
+        expected = dict()
+        expected['info'] = dict()
+        expected['warn'] = dict()
+        expected['error'] = dict()
+        name = c._get_check_name('files_usable')
+        expected['info'][name] = {"text": "OK"}
+        self.check_results(r, expected=expected)
+
+    def test_check_desktop_file_snappy_1604(self):
+        '''Test check_desktop_file() -  snappy 16.04'''
+        self.set_test_pkgfmt("snap", "16.04")
+        c = ClickReviewDesktop(self.test_name)
+        c.check_desktop_file()
+        r = c.click_report
+        expected = dict()
+        expected['info'] = dict()
+        expected['warn'] = dict()
+        expected['error'] = dict()
+        name = c._get_check_name('files_usable')
+        expected['info'][name] = {"text": "Skipped: could not find any desktop files"}
+        self.check_results(r, expected=expected)
