@@ -20,11 +20,6 @@ import clickreviews.cr_tests as cr_tests
 
 class TestClickReviewPushHelper(cr_tests.TestClickReview):
     """Tests for the lint review tool."""
-    def setUp(self):
-        # Monkey patch various file access classes. stop() is handled with
-        # addCleanup in super()
-        cr_tests.mock_patch()
-        super()
 
     def test_check_unknown_keys_none(self):
         '''Test check_unknown() - no unknown'''
@@ -206,3 +201,23 @@ class TestClickReviewPushHelper(cr_tests.TestClickReview):
         r = c.click_report
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
+
+    def test_check_valid_exec_snappy_1504(self):
+        '''Test check_valid() - exec - snappy 15.04'''
+        self.set_test_pkgfmt("snap", "15.04")
+        self.set_test_push_helper(self.default_appname, "exec", "foo")
+        c = ClickReviewPushHelper(self.test_name)
+        c.check_valid()
+        r = c.click_report
+        expected_counts = {'info': 2, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_valid_exec_snappy_1604(self):
+        '''Test check_valid() - exec - snappy 16.04'''
+        self.set_test_pkgfmt("snap", "16.04")
+        self.set_test_push_helper(self.default_appname, "exec", "foo")
+        c = ClickReviewPushHelper(self.test_name)
+        c.check_valid()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
